import { Line, Area, Bar, Column, Pie, DualAxes, Rose, Scatter, Stock, Mix, LineOptions, AreaOptions, BarOptions, ColumnOptions, PieOptions, DualAxesOptions, RoseOptions, ScatterOptions, StockOptions, MixOptions } from '@antv/g2plot';
import { ChartDatasourceErrorEvent } from './chart-datasource/chart-datasource.types';
import { chartErrorNames } from './chart.definitions';
/**
 * G2Plot Chart Config
 * @public
 */
export type ChartConfig = LineOptions | AreaOptions | BarOptions | ColumnOptions | PieOptions | DualAxesOptions | RoseOptions | ScatterOptions | StockOptions | MixOptions;
/**
 * G2Plot Chart Models
 * @public
 */
export type ChartModels = Line | Area | Bar | Column | Pie | DualAxes | Rose | Scatter | Stock | Mix;
/**
 * G2Plot Chart Types
 * @public
 */
export type ChartTypes = 'line' | 'area' | 'column' | 'bar' | 'pie' | 'donut' | 'dualaxes' | 'rose' | 'scatter' | 'stock' | 'mix';
/**
 * Chart Event Listeners
 * @internal
 */
export type ChartEventsListeners = {
    key: string;
    action: (event: Event) => void;
}[];
/**
 * Chart Error Types
 * @public
 */
export type ChartErrorTypes = keyof typeof chartErrorNames;
/**
 * Chart Error Item
 * @public
 */
export interface ChartErrorItem<ChartErrorItemDetailType> {
    detail: ChartErrorItemDetailType;
    type: ChartErrorTypes;
}
/**
 * Chart possible error events
 * @public
 */
export type ChartErrorEvent = ChartDatasourceErrorEvent | CustomEvent<ChartErrorItem<any>>;
//# sourceMappingURL=chart.types.d.ts.map