import { Area } from '@antv/g2plot';
import { AreaOptions } from '@antv/g2plot';
import { Bar } from '@antv/g2plot';
import { BarOptions } from '@antv/g2plot';
import { BaseDatasource } from '@genesislcap/foundation-ui';
import type { BaseDatasourceErrorHandlingOptions } from '@genesislcap/foundation-ui';
import { Column } from '@antv/g2plot';
import { ColumnOptions } from '@antv/g2plot';
import type { Container } from '@microsoft/fast-foundation';
import { Controller } from '@microsoft/fast-element';
import { DOMContainer } from '@genesislcap/foundation-utils';
import { DualAxes } from '@antv/g2plot';
import { DualAxesOptions } from '@antv/g2plot';
import { ElementStyles } from '@microsoft/fast-element';
import { FieldMetadata } from '@genesislcap/foundation-comms';
import { FoundationElement } from '@microsoft/fast-foundation';
import { FoundationElementRegistry } from '@microsoft/fast-foundation';
import { FoundationLayoutContainer } from '@genesislcap/foundation-utils';
import { LayoutCacheContainer } from '@genesislcap/foundation-utils';
import { Line } from '@antv/g2plot';
import { LineOptions } from '@antv/g2plot';
import { Mix } from '@antv/g2plot';
import { MixOptions } from '@antv/g2plot';
import { OverrideFoundationElementDefinition } from '@microsoft/fast-foundation';
import { Pie } from '@antv/g2plot';
import { PieOptions } from '@antv/g2plot';
import { Rose } from '@antv/g2plot';
import { RoseOptions } from '@antv/g2plot';
import { Scatter } from '@antv/g2plot';
import { ScatterOptions } from '@antv/g2plot';
import { Stock } from '@antv/g2plot';
import { StockOptions } from '@antv/g2plot';
import { ViewTemplate } from '@microsoft/fast-element';

/**
 * G2Plot Chart Config
 * @public
 */
export declare type ChartConfig = LineOptions | AreaOptions | BarOptions | ColumnOptions | PieOptions | DualAxesOptions | RoseOptions | ScatterOptions | StockOptions | MixOptions;

/**
 * The Genesis Datasource for the `g2plot-chart` component.
 * @public
 */
export declare class ChartDatasource extends ChartDatasource_base {
    /**
     * Default value is 'groupBy value'. Can be customized but order matters.
     *
     * [Mandatory] First is always the xField/colorField
     * [Mandatory] Second is always the yField/angleField
     * [Optional] Third is always the seriesField
     *
     * @public
     */
    chartFields: string;
    /**
     * Can be customized but order matters.
     *
     * [Mandatory] First will be associated to the first value in 'chartFields' (xField/colorField)
     * [Mandatory] Second will be associated to the second value in 'chartFields' (yField/angleField)
     * [Optional] Third will be associated to the third value in 'chartFields' (seriesField)
     *
     * @public
     */
    serverFields: string;
    /**
     * If true, will enable stacked chart to effectively portray comparisons of total values across several categories.
     * @public
     */
    isStack: boolean;
    /**
     * If true, will enable grouped chart plotting numeric values for levels of two categorical variables instead of one.
     * @public
     */
    isGroup: boolean;
    /**
     * Enabled by default, will not work if a custom charts-fields is used (requires [type, value]).
     * @public
     */
    reduced: boolean;
    /**
     * Only works if [withTimestampFormatting] is true.
     *
     * Disabled by default, will ignore the TIME portion in the Chart labels.
     * Only affects [DATETIME] fields.
     * @public
     */
    showFormattedTime: boolean;
    /**
     * Enabled by default, will format UNIX timestamp fields to readable [DATE|DATETIME] values.
     * @public
     */
    withTimestampFormatting: boolean;
    /**
     * Name of the backend resource which contain the data.
     * @public
     */
    resourceName: string;
    /**
     * Clients can send a Groovy expression to perform filters on the query server,
     * these remain active for the life of the subscription.
     * @public
     */
    criteria: string;
    /**
     * Optional attribute that can be used to pass the data that will be used in the component.
     * @public
     */
    data: any[];
    /**
     * Request a snapshot from the server.
     * @public
     */
    isSnapshot: boolean;
    /**
     * Maximum number of rows to be returned as part of the initial message,
     * and as part of any additional MORE_ROWS messages.
     * This will not affect the number of rows displayed.
     * @public
     */
    maxRows: number;
    /**
     * Maximum number of rows to track as part of a client "view".
     */
    maxView: number;
    /**
     * This option can be used to select a Data Server index (defined in the Data Server query),
     * which is especially useful if you want the data to be sorted in a specific way. By default,
     * Data Server rows are returned in order of creation (from oldest database record to newest).
     * @public
     */
    orderBy: string;
    /**
     * This optional parameter enables you to specify request fields, which can include wildcards.
     * @public
     */
    request: any;
    /**
     * This option changes the Data Server index iteration.
     * For example, if you are using the default index,
     * the query will return rows in order from the newest database records to the oldest.
     * @public
     */
    reverse: boolean;
    /**
     * Attribute to set an unique identifier for the row.
     * @public
     */
    rowId: string;
    /**
     * @internal
     */
    connectedCallback(): Promise<void>;
    /**
     * @internal
     */
    handleError(params: BaseDatasourceErrorHandlingOptions): void;
    /**
     * @internal
     */
    disconnectedCallback(): void;
    /**
     * @internal
     */
    fetchGenesisData(withFullInit?: boolean): Promise<void>;
    private prepareSeriesField;
    private prepareValidServerFieldsMetadata;
    /**
     * @internal
     */
    get hasValidServerFields(): boolean;
    /**
     * @internal
     */
    get hasValidChartFields(): boolean;
    private hasValidFieldsStructure;
}

declare const ChartDatasource_base: (new (...args: any[]) => {
    "__#1@#_container": FoundationLayoutContainer | LayoutCacheContainer | DOMContainer;
    "__#1@#_latestTokenCode": string;
    "__#1@#_hasFirstLoaded": boolean;
    "__#1@#_cleanupTimeout": NodeJS.Timeout;
    "__#1@#_shouldForceLifecycle": boolean;
    cloneNode(deep?: boolean): Node;
    deepClone(): Node;
    readonly shouldRunDisconnect: boolean;
    readonly shouldRunConnect: boolean;
    "__#1@#_blockLifecycleDueToTokenChange"(lifecycleType: "connect" | "disconnect" | "reconnect"): boolean;
    "__#1@#_tryFindContainingLayout"(e: Element): FoundationLayoutContainer | LayoutCacheContainer | DOMContainer;
    connectedCallback(): void;
    readonly $fastController: Controller;
    $emit(type: string, detail?: any, options?: Omit<CustomEventInit<any>, "detail">): boolean | void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    accessKey: string;
    readonly accessKeyLabel: string;
    autocapitalize: string;
    dir: string;
    draggable: boolean;
    hidden: boolean;
    inert: boolean; /**
    * If true, will enable grouped chart plotting numeric values for levels of two categorical variables instead of one.
    * @public
    */
    innerText: string;
    lang: string;
    readonly offsetHeight: number;
    readonly offsetLeft: number;
    readonly offsetParent: Element;
    readonly offsetTop: number;
    readonly offsetWidth: number;
    outerText: string;
    spellcheck: boolean;
    title: string;
    translate: boolean;
    attachInternals(): ElementInternals;
    click(): void;
    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;
    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;
    removeEventListener<K_1 extends keyof HTMLElementEventMap>(type: K_1, listener: (this: HTMLElement, ev: HTMLElementEventMap[K_1]) => any, options?: boolean | EventListenerOptions): void;
    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;
    readonly attributes: NamedNodeMap;
    readonly classList: DOMTokenList;
    className: string;
    readonly clientHeight: number;
    readonly clientLeft: number;
    readonly clientTop: number;
    readonly clientWidth: number;
    id: string;
    readonly localName: string;
    readonly namespaceURI: string;
    onfullscreenchange: (this: Element, ev: Event) => any;
    onfullscreenerror: (this: Element, ev: Event) => any;
    outerHTML: string;
    readonly ownerDocument: Document;
    readonly part: DOMTokenList;
    readonly prefix: string;
    readonly scrollHeight: number;
    scrollLeft: number;
    scrollTop: number;
    readonly scrollWidth: number;
    readonly shadowRoot: ShadowRoot;
    slot: string;
    readonly tagName: string;
    attachShadow(init: ShadowRootInit): ShadowRoot;
    closest<K_2 extends keyof HTMLElementTagNameMap>(selector: K_2): HTMLElementTagNameMap[K_2];
    closest<K_3 extends keyof SVGElementTagNameMap>(selector: K_3): SVGElementTagNameMap[K_3];
    closest<E extends Element = Element>(selectors: string): E;
    getAttribute(qualifiedName: string): string;
    getAttributeNS(namespace: string, localName: string): string;
    getAttributeNames(): string[];
    getAttributeNode(qualifiedName: string): Attr;
    getAttributeNodeNS(namespace: string, localName: string): Attr;
    getBoundingClientRect(): DOMRect;
    getClientRects(): DOMRectList;
    getElementsByClassName(classNames: string): HTMLCollectionOf<Element>;
    getElementsByTagName<K_4 extends keyof HTMLElementTagNameMap>(qualifiedName: K_4): HTMLCollectionOf<HTMLElementTagNameMap[K_4]>;
    getElementsByTagName<K_5 extends keyof SVGElementTagNameMap>(qualifiedName: K_5): HTMLCollectionOf<SVGElementTagNameMap[K_5]>;
    getElementsByTagName(qualifiedName: string): HTMLCollectionOf<Element>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/1999/xhtml", localName: string): HTMLCollectionOf<HTMLElement>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/2000/svg", localName: string): HTMLCollectionOf<SVGElement>;
    getElementsByTagNameNS(namespace: string, localName: string): HTMLCollectionOf<Element>;
    hasAttribute(qualifiedName: string): boolean;
    hasAttributeNS(namespace: string, localName: string): boolean;
    hasAttributes(): boolean;
    hasPointerCapture(pointerId: number): boolean;
    insertAdjacentElement(where: InsertPosition, element: Element): Element;
    insertAdjacentHTML(position: InsertPosition, text: string): void;
    insertAdjacentText(where: InsertPosition, data: string): void;
    matches(selectors: string): boolean;
    releasePointerCapture(pointerId: number): void;
    removeAttribute(qualifiedName: string): void;
    removeAttributeNS(namespace: string, localName: string): void;
    removeAttributeNode(attr: Attr): Attr;
    requestFullscreen(options?: FullscreenOptions): Promise<void>;
    requestPointerLock(): void;
    scroll(options?: ScrollToOptions): void;
    scroll(x: number, y: number): void;
    scrollBy(options?: ScrollToOptions): void;
    scrollBy(x: number, y: number): void;
    scrollIntoView(arg?: boolean | ScrollIntoViewOptions): void;
    scrollTo(options?: ScrollToOptions): void;
    scrollTo(x: number, y: number): void;
    setAttribute(qualifiedName: string, value: string): void;
    setAttributeNS(namespace: string, qualifiedName: string, value: string): void;
    setAttributeNode(attr: Attr): Attr;
    setAttributeNodeNS(attr: Attr): Attr;
    setPointerCapture(pointerId: number): void;
    toggleAttribute(qualifiedName: string, force?: boolean): boolean;
    webkitMatchesSelector(selectors: string): boolean;
    readonly baseURI: string;
    readonly childNodes: NodeListOf<ChildNode>;
    readonly firstChild: ChildNode;
    readonly isConnected: boolean;
    readonly lastChild: ChildNode;
    readonly nextSibling: ChildNode;
    readonly nodeName: string;
    readonly nodeType: number;
    nodeValue: string;
    readonly parentElement: HTMLElement;
    readonly parentNode: ParentNode;
    readonly previousSibling: ChildNode;
    textContent: string;
    appendChild<T_1 extends Node>(node: T_1): T_1;
    compareDocumentPosition(other: Node): number;
    contains(other: Node): boolean;
    getRootNode(options?: GetRootNodeOptions): Node;
    hasChildNodes(): boolean;
    insertBefore<T_2 extends Node>(node: T_2, child: Node): T_2;
    isDefaultNamespace(namespace: string): boolean;
    isEqualNode(otherNode: Node): boolean;
    isSameNode(otherNode: Node): boolean;
    lookupNamespaceURI(prefix: string): string;
    lookupPrefix(namespace: string): string;
    normalize(): void;
    removeChild<T_3 extends Node>(child: T_3): T_3;
    replaceChild<T_4 extends Node>(node: Node, child: T_4): T_4;
    readonly ATTRIBUTE_NODE: number;
    readonly CDATA_SECTION_NODE: number;
    readonly COMMENT_NODE: number;
    readonly DOCUMENT_FRAGMENT_NODE: number;
    readonly DOCUMENT_NODE: number;
    readonly DOCUMENT_POSITION_CONTAINED_BY: number;
    readonly DOCUMENT_POSITION_CONTAINS: number;
    readonly DOCUMENT_POSITION_DISCONNECTED: number;
    readonly DOCUMENT_POSITION_FOLLOWING: number;
    readonly DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: number;
    readonly DOCUMENT_POSITION_PRECEDING: number;
    readonly DOCUMENT_TYPE_NODE: number;
    readonly ELEMENT_NODE: number;
    readonly ENTITY_NODE: number;
    readonly ENTITY_REFERENCE_NODE: number;
    readonly NOTATION_NODE: number;
    readonly PROCESSING_INSTRUCTION_NODE: number;
    readonly TEXT_NODE: number;
    dispatchEvent(event: Event): boolean;
    ariaAtomic: string;
    ariaAutoComplete: string;
    ariaBusy: string;
    ariaChecked: string;
    ariaColCount: string;
    ariaColIndex: string;
    ariaColIndexText: string;
    ariaColSpan: string;
    ariaCurrent: string;
    ariaDisabled: string;
    ariaExpanded: string;
    ariaHasPopup: string;
    ariaHidden: string;
    ariaInvalid: string;
    ariaKeyShortcuts: string;
    ariaLabel: string;
    ariaLevel: string;
    ariaLive: string;
    ariaModal: string;
    ariaMultiLine: string;
    ariaMultiSelectable: string;
    ariaOrientation: string;
    ariaPlaceholder: string;
    ariaPosInSet: string;
    ariaPressed: string;
    ariaReadOnly: string;
    ariaRequired: string;
    ariaRoleDescription: string;
    ariaRowCount: string;
    ariaRowIndex: string;
    ariaRowIndexText: string;
    ariaRowSpan: string;
    ariaSelected: string;
    ariaSetSize: string;
    ariaSort: string;
    ariaValueMax: string;
    ariaValueMin: string;
    ariaValueNow: string;
    ariaValueText: string;
    role: string;
    animate(keyframes: PropertyIndexedKeyframes | Keyframe[], options?: number | KeyframeAnimationOptions): Animation;
    getAnimations(options?: GetAnimationsOptions): Animation[];
    after(...nodes: (string | Node)[]): void;
    before(...nodes: (string | Node)[]): void;
    remove(): void;
    replaceWith(...nodes: (string | Node)[]): void;
    innerHTML: string;
    readonly nextElementSibling: Element;
    readonly previousElementSibling: Element;
    readonly childElementCount: number;
    readonly children: HTMLCollection;
    readonly firstElementChild: Element;
    readonly lastElementChild: Element;
    append(...nodes: (string | Node)[]): void;
    prepend(...nodes: (string | Node)[]): void;
    querySelector<K_6 extends keyof HTMLElementTagNameMap>(selectors: K_6): HTMLElementTagNameMap[K_6];
    querySelector<K_7 extends keyof SVGElementTagNameMap>(selectors: K_7): SVGElementTagNameMap[K_7];
    querySelector<E_1 extends Element = Element>(selectors: string): E_1;
    querySelectorAll<K_8 extends keyof HTMLElementTagNameMap>(selectors: K_8): NodeListOf<HTMLElementTagNameMap[K_8]>;
    querySelectorAll<K_9 extends keyof SVGElementTagNameMap>(selectors: K_9): NodeListOf<SVGElementTagNameMap[K_9]>;
    querySelectorAll<E_2 extends Element = Element>(selectors: string): NodeListOf<E_2>;
    replaceChildren(...nodes: (string | Node)[]): void;
    readonly assignedSlot: HTMLSlotElement;
    oncopy: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    oncut: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    onpaste: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    readonly style: CSSStyleDeclaration;
    contentEditable: string;
    enterKeyHint: string;
    inputMode: string;
    readonly isContentEditable: boolean;
    onabort: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onanimationcancel: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationend: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationiteration: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationstart: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onauxclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onbeforeinput: (this: GlobalEventHandlers, ev: InputEvent) => any;
    onblur: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    oncancel: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplay: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplaythrough: (this: GlobalEventHandlers, ev: Event) => any;
    onchange: (this: GlobalEventHandlers, ev: Event) => any;
    onclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onclose: (this: GlobalEventHandlers, ev: Event) => any;
    oncontextmenu: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    oncuechange: (this: GlobalEventHandlers, ev: Event) => any;
    ondblclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    ondrag: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragend: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragenter: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragleave: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragover: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragstart: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondrop: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondurationchange: (this: GlobalEventHandlers, ev: Event) => any;
    onemptied: (this: GlobalEventHandlers, ev: Event) => any;
    onended: (this: GlobalEventHandlers, ev: Event) => any;
    onerror: OnErrorEventHandlerNonNull;
    onfocus: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    onformdata: (this: GlobalEventHandlers, ev: FormDataEvent) => any;
    ongotpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    oninput: (this: GlobalEventHandlers, ev: Event) => any;
    oninvalid: (this: GlobalEventHandlers, ev: Event) => any;
    onkeydown: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeypress: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeyup: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onload: (this: GlobalEventHandlers, ev: Event) => any;
    onloadeddata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadedmetadata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadstart: (this: GlobalEventHandlers, ev: Event) => any;
    onlostpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onmousedown: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseenter: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseleave: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmousemove: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseout: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseover: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseup: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onpause: (this: GlobalEventHandlers, ev: Event) => any;
    onplay: (this: GlobalEventHandlers, ev: Event) => any;
    onplaying: (this: GlobalEventHandlers, ev: Event) => any;
    onpointercancel: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerdown: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerenter: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerleave: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointermove: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerout: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerover: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerup: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onprogress: (this: GlobalEventHandlers, ev: ProgressEvent<EventTarget>) => any;
    onratechange: (this: GlobalEventHandlers, ev: Event) => any;
    onreset: (this: GlobalEventHandlers, ev: Event) => any;
    onresize: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onscroll: (this: GlobalEventHandlers, ev: Event) => any;
    onsecuritypolicyviolation: (this: GlobalEventHandlers, ev: SecurityPolicyViolationEvent) => any;
    onseeked: (this: GlobalEventHandlers, ev: Event) => any;
    onseeking: (this: GlobalEventHandlers, ev: Event) => any;
    onselect: (this: GlobalEventHandlers, ev: Event) => any;
    onselectionchange: (this: GlobalEventHandlers, ev: Event) => any;
    onselectstart: (this: GlobalEventHandlers, ev: Event) => any;
    onslotchange: (this: GlobalEventHandlers, ev: Event) => any;
    onstalled: (this: GlobalEventHandlers, ev: Event) => any;
    onsubmit: (this: GlobalEventHandlers, ev: SubmitEvent) => any;
    onsuspend: (this: GlobalEventHandlers, ev: Event) => any;
    ontimeupdate: (this: GlobalEventHandlers, ev: Event) => any;
    ontoggle: (this: GlobalEventHandlers, ev: Event) => any;
    ontouchcancel?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchend?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchmove?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchstart?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontransitioncancel: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionend: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionrun: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionstart: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    onvolumechange: (this: GlobalEventHandlers, ev: Event) => any;
    onwaiting: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationend: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationiteration: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationstart: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkittransitionend: (this: GlobalEventHandlers, ev: Event) => any;
    onwheel: (this: GlobalEventHandlers, ev: WheelEvent) => any;
    autofocus: boolean;
    readonly dataset: DOMStringMap;
    nonce?: string;
    tabIndex: number;
    blur(): void;
    focus(options?: FocusOptions): void;
}) & typeof ConcreteDatasource;

/**
 * The error event Chart Datasource.
 * @public
 */
export declare type ChartDatasourceErrorEvent = CustomEvent<ChartDatasourceErrorEventDetail>;

/**
 * The event detail for the Chart Datasource `error` event.
 * @public
 */
export declare type ChartDatasourceErrorEventDetail = {
    message: string;
};

/**
 * The Chart Datasource event names.
 * @public
 */
export declare const chartDatasourceEventNames: {
    error: string;
};

/**
 * Chart possible error events
 * @public
 */
export declare type ChartErrorEvent = ChartDatasourceErrorEvent | CustomEvent<ChartErrorItem<any>>;

/**
 * Chart Error Item
 * @public
 */
export declare interface ChartErrorItem<ChartErrorItemDetailType> {
    detail: ChartErrorItemDetailType;
    type: ChartErrorTypes;
}

/**
 * The error names for the Chart component.
 * @public
 */
export declare const chartErrorNames: {
    readonly datasource: "datasource";
    readonly unknown: "unknown";
};

/**
 * Chart Error Types
 * @public
 */
export declare type ChartErrorTypes = keyof typeof chartErrorNames;

/**
 * The Chart Datasource events names.
 * @internal
 */
export declare const chartEventNames: {
    datasourceErrorClose: string;
};

/**
 * Chart Event Listeners
 * @internal
 */
export declare type ChartEventsListeners = {
    key: string;
    action: (event: Event) => void;
}[];

/**
 * G2Plot Chart Models
 * @public
 */
export declare type ChartModels = Line | Area | Bar | Column | Pie | DualAxes | Rose | Scatter | Stock | Mix;

/**
 * G2Plot Chart gradient colors
 * @public
 */
export declare const chartsGradients: {
    rapidBlue: string;
    rapidGreen: string;
    rapidRed: string;
    rapidPortage: string;
    rapidAlabaster: string;
    rapidSalomie: string;
    rapidMelon: string;
    rapidDodgerBlue: string;
    rapidIce: string;
    rapidViolet: string;
};

/**
 * G2Plot Chart Types
 * @public
 */
export declare type ChartTypes = 'line' | 'area' | 'column' | 'bar' | 'pie' | 'donut' | 'dualaxes' | 'rose' | 'scatter' | 'stock' | 'mix';

declare class ConcreteDatasource extends BaseDatasource {
    protected chart: G2PlotChart;
    protected extractedServerFields: string[];
    protected validServerFieldsMetadata: Map<string, FieldMetadata>;
    protected seriesChartField: string;
    protected extractedChartsFields: string[];
    protected showFormattedTime: boolean;
    protected reduced: boolean;
    get groupByServerFieldName(): string;
    clearData(): void;
    syncComponentData(snapshotData?: any[]): void;
    handleStreamInserts(insertedRows: any[]): void;
    handleStreamDeletes(deletedRows: any[]): void;
    handleStreamUpdates(updatedRows: any[]): void;
}

/**
 * The default `g2plot-chart` configuration.
 * @public
 */
export declare const defaultChartConfig: {};

/**
 * The first and second default chart fields when it's a dual axes chart.
 * @remarks This field is always used. Default value is 'groupBy value'.
 * @public
 */
export declare const defaultChartFields = "groupBy value";

/**
 * The third default chart field when it's a triple axes chart.
 * @remarks This field is optional. Default value is 'series'.
 * @public
 */
export declare const defaultSeriesChartField = "series";

/**
 * The `g2plot-chart` component shadow options.
 * @public
 * @privateRemarks explicitly declaring for extensibility
 */
export declare const foundationChartShadowOptions: ShadowRootInit;

/**
 * The G2Plot Chart component
 * @public
 * @tagname %%prefix%%-g2plot-chart
 */
export declare class G2PlotChart extends G2PlotChart_base {
    private chart;
    /**
     * @internal
     */
    chartContainer: HTMLElement;
    /**
     * The type to use for the chart. If not set, the default bar type will be used.
     * @remarks Can be one of the following: line, area, column, bar, pie, donut, dualaxes, rose, scatter, stock, mix.
     * @public
     */
    type: ChartTypes;
    /**
     * The configuration to use for the chart.
     * Check {@link ChartConfig} for possible options
     *
     * @example
     * Here's a simple example:
     * ```
     * const chartConfig = {
     *   width: 700,
     *   xField: 'value',
     *   yField: 'groupBy',
     *   seriesField: 'series',
     *   legend: {
     *     position: 'top-left',
     *   },
     * };
     * ```
     * @public
     */
    config: ChartConfig;
    /**
     * @internal
     */
    configChanged(): void;
    /**
     * The data to display in the chart.
     * @remarks For scenarios where you want to set data manually, without relying on `<chart-datasource>`.
     * @public
     */
    data: any[];
    /**
     * @internal
     */
    dataChanged(oldValue: any[], newValue: any[]): void;
    /**
     * @internal
     */
    errorItems: ChartErrorItem<ChartErrorEvent['detail']>[];
    private legendSelected;
    private legendParser?;
    private rootEventsListeners;
    /**
     * @internal
     */
    constructor();
    private hideDatasourceError;
    private addErrorItem;
    /**
     * Override the deepClone method to ensure that observable attributes are cloned
     * @internal
     */
    deepClone(): Node;
    /**
     * Initializing and rendering chart component.
     * @internal
     */
    renderChart(): void;
    /**
     * Set up the web component
     * @internal
     */
    connectedCallback(): void;
    /**
     * @internal
     */
    disconnectedCallback(): void;
    /**
     * @internal
     */
    eventHandler: (e: any) => void;
    /**
     * Initializing a chart component based on type.
     * @internal
     */
    private initalizeChart;
    private getLegendNameFromData;
    /**
     * Get which legend items are selected (shown/hidden) so they can be re-applied during a subsequent connectedCallback
     *
     * @remarks
     * When moving a chart around with `appendChild()` the state of hidden/shown fields is reset. This callback function
     * will cache the state of the legend items so they can be re-applied when the chart is re-rendered. The cache
     * is applied in `this.initalizeConfiguration()`.
     *
     * To get the state of the legend items, the chart's `filteredData` is used. This is the data that is currently
     * shown on the chart. If we diff this with all of the data from `this.data` we can work out which fields are hidden or shown.
     *
     * To get the legend name from the data to pass to the options we use a legend parser which is a function that takes a single
     * data item and extracts the legend name from it. There are defaults for certain chart types in `this.getLegendNameFromData`
     * but this can be overridden by passing a `legendParser` function to the chart.
     */
    private cacheHiddenLegendItemsCallback;
    private initalizeConfiguration;
}

/**
 * The G2plot Chart
 *
 * @internal
 * @remarks
 * HTML Element: \<design-system-g2plot-chart\>
 */
export declare const g2plotChart: (overrideDefinition?: OverrideFoundationElementDefinition<    {
baseName: string;
styles: ElementStyles;
template: ViewTemplate<any, any>;
shadowOptions: ShadowRootInit;
}>) => FoundationElementRegistry<    {
baseName: string;
styles: ElementStyles;
template: ViewTemplate<any, any>;
shadowOptions: ShadowRootInit;
}, typeof G2PlotChart>;

declare const G2PlotChart_base: (new (...args: any[]) => {
    "__#1@#_container": FoundationLayoutContainer | LayoutCacheContainer | DOMContainer;
    "__#1@#_latestTokenCode": string;
    "__#1@#_hasFirstLoaded": boolean;
    "__#1@#_cleanupTimeout": NodeJS.Timeout;
    "__#1@#_shouldForceLifecycle": boolean;
    cloneNode(deep?: boolean): Node;
    deepClone(): Node;
    readonly shouldRunDisconnect: boolean;
    readonly shouldRunConnect: boolean;
    "__#1@#_blockLifecycleDueToTokenChange"(lifecycleType: "connect" | "disconnect" | "reconnect"): boolean;
    "__#1@#_tryFindContainingLayout"(e: Element): FoundationLayoutContainer | LayoutCacheContainer | DOMContainer;
    connectedCallback(): void;
    readonly $fastController: Controller;
    $emit(type: string, detail?: any, options?: Omit<CustomEventInit<any>, "detail">): boolean | void;
    disconnectedCallback(): void;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    accessKey: string;
    readonly accessKeyLabel: string;
    autocapitalize: string;
    dir: string;
    draggable: boolean;
    hidden: boolean;
    inert: boolean;
    innerText: string;
    lang: string;
    readonly offsetHeight: number;
    readonly offsetLeft: number;
    readonly offsetParent: Element;
    readonly offsetTop: number;
    readonly offsetWidth: number;
    outerText: string;
    spellcheck: boolean;
    title: string;
    translate: boolean;
    attachInternals(): ElementInternals;
    click(): void;
    addEventListener<K extends keyof HTMLElementEventMap>(type: K, listener: (this: HTMLElement, ev: HTMLElementEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;
    addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;
    removeEventListener<K_1 extends keyof HTMLElementEventMap>(type: K_1, listener: (this: HTMLElement, ev: HTMLElementEventMap[K_1]) => any, options?: boolean | EventListenerOptions): void;
    removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;
    readonly attributes: NamedNodeMap;
    readonly classList: DOMTokenList;
    className: string;
    readonly clientHeight: number;
    readonly clientLeft: number;
    readonly clientTop: number;
    readonly clientWidth: number;
    id: string;
    readonly localName: string;
    readonly namespaceURI: string;
    onfullscreenchange: (this: Element, ev: Event) => any;
    onfullscreenerror: (this: Element, ev: Event) => any;
    outerHTML: string;
    readonly ownerDocument: Document;
    readonly part: DOMTokenList;
    readonly prefix: string;
    readonly scrollHeight: number;
    scrollLeft: number;
    scrollTop: number;
    readonly scrollWidth: number;
    readonly shadowRoot: ShadowRoot;
    slot: string;
    readonly tagName: string;
    attachShadow(init: ShadowRootInit): ShadowRoot;
    closest<K_2 extends keyof HTMLElementTagNameMap>(selector: K_2): HTMLElementTagNameMap[K_2];
    closest<K_3 extends keyof SVGElementTagNameMap>(selector: K_3): SVGElementTagNameMap[K_3];
    closest<E extends Element = Element>(selectors: string): E;
    getAttribute(qualifiedName: string): string;
    getAttributeNS(namespace: string, localName: string): string;
    getAttributeNames(): string[];
    getAttributeNode(qualifiedName: string): Attr;
    getAttributeNodeNS(namespace: string, localName: string): Attr;
    getBoundingClientRect(): DOMRect;
    getClientRects(): DOMRectList;
    getElementsByClassName(classNames: string): HTMLCollectionOf<Element>;
    getElementsByTagName<K_4 extends keyof HTMLElementTagNameMap>(qualifiedName: K_4): HTMLCollectionOf<HTMLElementTagNameMap[K_4]>;
    getElementsByTagName<K_5 extends keyof SVGElementTagNameMap>(qualifiedName: K_5): HTMLCollectionOf<SVGElementTagNameMap[K_5]>;
    getElementsByTagName(qualifiedName: string): HTMLCollectionOf<Element>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/1999/xhtml", localName: string): HTMLCollectionOf<HTMLElement>;
    getElementsByTagNameNS(namespaceURI: "http://www.w3.org/2000/svg", localName: string): HTMLCollectionOf<SVGElement>;
    getElementsByTagNameNS(namespace: string, localName: string): HTMLCollectionOf<Element>;
    hasAttribute(qualifiedName: string): boolean;
    hasAttributeNS(namespace: string, localName: string): boolean;
    hasAttributes(): boolean;
    hasPointerCapture(pointerId: number): boolean;
    insertAdjacentElement(where: InsertPosition, element: Element): Element;
    insertAdjacentHTML(position: InsertPosition, text: string): void;
    insertAdjacentText(where: InsertPosition, data: string): void;
    matches(selectors: string): boolean;
    releasePointerCapture(pointerId: number): void;
    removeAttribute(qualifiedName: string): void;
    removeAttributeNS(namespace: string, localName: string): void;
    removeAttributeNode(attr: Attr): Attr;
    requestFullscreen(options?: FullscreenOptions): Promise<void>;
    requestPointerLock(): void;
    scroll(options?: ScrollToOptions): void;
    scroll(x: number, y: number): void;
    scrollBy(options?: ScrollToOptions): void;
    scrollBy(x: number, y: number): void;
    scrollIntoView(arg?: boolean | ScrollIntoViewOptions): void;
    scrollTo(options?: ScrollToOptions): void;
    scrollTo(x: number, y: number): void;
    setAttribute(qualifiedName: string, value: string): void;
    setAttributeNS(namespace: string, qualifiedName: string, value: string): void;
    setAttributeNode(attr: Attr): Attr;
    setAttributeNodeNS(attr: Attr): Attr;
    setPointerCapture(pointerId: number): void;
    toggleAttribute(qualifiedName: string, force?: boolean): boolean;
    webkitMatchesSelector(selectors: string): boolean;
    readonly baseURI: string;
    readonly childNodes: NodeListOf<ChildNode>;
    readonly firstChild: ChildNode;
    readonly isConnected: boolean;
    readonly lastChild: ChildNode;
    readonly nextSibling: ChildNode;
    readonly nodeName: string;
    readonly nodeType: number;
    nodeValue: string;
    readonly parentElement: HTMLElement;
    readonly parentNode: ParentNode;
    readonly previousSibling: ChildNode;
    textContent: string;
    appendChild<T_1 extends Node>(node: T_1): T_1;
    compareDocumentPosition(other: Node): number;
    contains(other: Node): boolean;
    getRootNode(options?: GetRootNodeOptions): Node;
    hasChildNodes(): boolean;
    insertBefore<T_2 extends Node>(node: T_2, child: Node): T_2;
    isDefaultNamespace(namespace: string): boolean;
    isEqualNode(otherNode: Node): boolean;
    isSameNode(otherNode: Node): boolean;
    lookupNamespaceURI(prefix: string): string;
    lookupPrefix(namespace: string): string;
    normalize(): void;
    removeChild<T_3 extends Node>(child: T_3): T_3;
    replaceChild<T_4 extends Node>(node: Node, child: T_4): T_4;
    readonly ATTRIBUTE_NODE: number;
    readonly CDATA_SECTION_NODE: number;
    readonly COMMENT_NODE: number;
    readonly DOCUMENT_FRAGMENT_NODE: number;
    readonly DOCUMENT_NODE: number;
    readonly DOCUMENT_POSITION_CONTAINED_BY: number;
    readonly DOCUMENT_POSITION_CONTAINS: number;
    readonly DOCUMENT_POSITION_DISCONNECTED: number;
    readonly DOCUMENT_POSITION_FOLLOWING: number;
    readonly DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: number;
    readonly DOCUMENT_POSITION_PRECEDING: number;
    readonly DOCUMENT_TYPE_NODE: number;
    readonly ELEMENT_NODE: number;
    readonly ENTITY_NODE: number;
    readonly ENTITY_REFERENCE_NODE: number;
    readonly NOTATION_NODE: number;
    readonly PROCESSING_INSTRUCTION_NODE: number;
    readonly TEXT_NODE: number;
    dispatchEvent(event: Event): boolean;
    ariaAtomic: string;
    ariaAutoComplete: string;
    ariaBusy: string;
    ariaChecked: string;
    ariaColCount: string;
    ariaColIndex: string;
    ariaColIndexText: string;
    ariaColSpan: string;
    ariaCurrent: string;
    ariaDisabled: string;
    ariaExpanded: string;
    ariaHasPopup: string;
    ariaHidden: string;
    ariaInvalid: string;
    ariaKeyShortcuts: string;
    ariaLabel: string;
    ariaLevel: string;
    ariaLive: string;
    ariaModal: string;
    ariaMultiLine: string;
    ariaMultiSelectable: string;
    ariaOrientation: string;
    ariaPlaceholder: string;
    ariaPosInSet: string;
    ariaPressed: string;
    ariaReadOnly: string;
    ariaRequired: string;
    ariaRoleDescription: string;
    ariaRowCount: string;
    ariaRowIndex: string;
    ariaRowIndexText: string;
    ariaRowSpan: string;
    ariaSelected: string;
    ariaSetSize: string;
    ariaSort: string;
    ariaValueMax: string;
    ariaValueMin: string;
    ariaValueNow: string;
    ariaValueText: string;
    role: string;
    animate(keyframes: PropertyIndexedKeyframes | Keyframe[], options?: number | KeyframeAnimationOptions): Animation;
    getAnimations(options?: GetAnimationsOptions): Animation[];
    after(...nodes: (string | Node)[]): void;
    before(...nodes: (string | Node)[]): void;
    remove(): void;
    replaceWith(...nodes: (string | Node)[]): void;
    innerHTML: string;
    readonly nextElementSibling: Element;
    readonly previousElementSibling: Element;
    readonly childElementCount: number;
    readonly children: HTMLCollection;
    readonly firstElementChild: Element;
    readonly lastElementChild: Element;
    append(...nodes: (string | Node)[]): void;
    prepend(...nodes: (string | Node)[]): void;
    querySelector<K_6 extends keyof HTMLElementTagNameMap>(selectors: K_6): HTMLElementTagNameMap[K_6];
    querySelector<K_7 extends keyof SVGElementTagNameMap>(selectors: K_7): SVGElementTagNameMap[K_7];
    querySelector<E_1 extends Element = Element>(selectors: string): E_1;
    querySelectorAll<K_8 extends keyof HTMLElementTagNameMap>(selectors: K_8): NodeListOf<HTMLElementTagNameMap[K_8]>;
    querySelectorAll<K_9 extends keyof SVGElementTagNameMap>(selectors: K_9): NodeListOf<SVGElementTagNameMap[K_9]>;
    querySelectorAll<E_2 extends Element = Element>(selectors: string): NodeListOf<E_2>;
    replaceChildren(...nodes: (string | Node)[]): void;
    readonly assignedSlot: HTMLSlotElement;
    oncopy: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    oncut: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    onpaste: (this: DocumentAndElementEventHandlers, ev: ClipboardEvent) => any;
    readonly style: CSSStyleDeclaration;
    contentEditable: string;
    enterKeyHint: string;
    inputMode: string;
    readonly isContentEditable: boolean;
    onabort: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onanimationcancel: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationend: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationiteration: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onanimationstart: (this: GlobalEventHandlers, ev: AnimationEvent) => any;
    onauxclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onbeforeinput: (this: GlobalEventHandlers, ev: InputEvent) => any;
    onblur: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    oncancel: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplay: (this: GlobalEventHandlers, ev: Event) => any;
    oncanplaythrough: (this: GlobalEventHandlers, ev: Event) => any;
    onchange: (this: GlobalEventHandlers, ev: Event) => any;
    onclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onclose: (this: GlobalEventHandlers, ev: Event) => any;
    oncontextmenu: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    oncuechange: (this: GlobalEventHandlers, ev: Event) => any;
    ondblclick: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    ondrag: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragend: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragenter: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragleave: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragover: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondragstart: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondrop: (this: GlobalEventHandlers, ev: DragEvent) => any;
    ondurationchange: (this: GlobalEventHandlers, ev: Event) => any;
    onemptied: (this: GlobalEventHandlers, ev: Event) => any;
    onended: (this: GlobalEventHandlers, ev: Event) => any;
    onerror: OnErrorEventHandlerNonNull;
    onfocus: (this: GlobalEventHandlers, ev: FocusEvent) => any;
    onformdata: (this: GlobalEventHandlers, ev: FormDataEvent) => any;
    ongotpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    oninput: (this: GlobalEventHandlers, ev: Event) => any;
    oninvalid: (this: GlobalEventHandlers, ev: Event) => any;
    onkeydown: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeypress: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onkeyup: (this: GlobalEventHandlers, ev: KeyboardEvent) => any;
    onload: (this: GlobalEventHandlers, ev: Event) => any;
    onloadeddata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadedmetadata: (this: GlobalEventHandlers, ev: Event) => any;
    onloadstart: (this: GlobalEventHandlers, ev: Event) => any;
    onlostpointercapture: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onmousedown: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseenter: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseleave: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmousemove: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseout: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseover: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onmouseup: (this: GlobalEventHandlers, ev: MouseEvent) => any;
    onpause: (this: GlobalEventHandlers, ev: Event) => any;
    onplay: (this: GlobalEventHandlers, ev: Event) => any;
    onplaying: (this: GlobalEventHandlers, ev: Event) => any;
    onpointercancel: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerdown: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerenter: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerleave: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointermove: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerout: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerover: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onpointerup: (this: GlobalEventHandlers, ev: PointerEvent) => any;
    onprogress: (this: GlobalEventHandlers, ev: ProgressEvent<EventTarget>) => any;
    onratechange: (this: GlobalEventHandlers, ev: Event) => any;
    onreset: (this: GlobalEventHandlers, ev: Event) => any;
    onresize: (this: GlobalEventHandlers, ev: UIEvent) => any;
    onscroll: (this: GlobalEventHandlers, ev: Event) => any;
    onsecuritypolicyviolation: (this: GlobalEventHandlers, ev: SecurityPolicyViolationEvent) => any;
    onseeked: (this: GlobalEventHandlers, ev: Event) => any;
    onseeking: (this: GlobalEventHandlers, ev: Event) => any;
    onselect: (this: GlobalEventHandlers, ev: Event) => any;
    onselectionchange: (this: GlobalEventHandlers, ev: Event) => any;
    onselectstart: (this: GlobalEventHandlers, ev: Event) => any;
    onslotchange: (this: GlobalEventHandlers, ev: Event) => any;
    onstalled: (this: GlobalEventHandlers, ev: Event) => any;
    onsubmit: (this: GlobalEventHandlers, ev: SubmitEvent) => any;
    onsuspend: (this: GlobalEventHandlers, ev: Event) => any;
    ontimeupdate: (this: GlobalEventHandlers, ev: Event) => any;
    ontoggle: (this: GlobalEventHandlers, ev: Event) => any;
    ontouchcancel?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchend?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchmove?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontouchstart?: (this: GlobalEventHandlers, ev: TouchEvent) => any;
    ontransitioncancel: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionend: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionrun: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    ontransitionstart: (this: GlobalEventHandlers, ev: TransitionEvent) => any;
    onvolumechange: (this: GlobalEventHandlers, ev: Event) => any;
    onwaiting: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationend: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationiteration: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkitanimationstart: (this: GlobalEventHandlers, ev: Event) => any;
    onwebkittransitionend: (this: GlobalEventHandlers, ev: Event) => any;
    onwheel: (this: GlobalEventHandlers, ev: WheelEvent) => any;
    autofocus: boolean;
    readonly dataset: DOMStringMap;
    nonce?: string;
    tabIndex: number;
    blur(): void;
    focus(options?: FocusOptions): void;
}) & typeof FoundationElement;

/**
 * All the `g2plot-chart` components
 * @public
 */
export declare const g2plotChartsComponents: {
    g2plotChart: (overrideDefinition?: OverrideFoundationElementDefinition<    {
    baseName: string;
    styles: ElementStyles;
    template: ViewTemplate<any, any>;
    shadowOptions: ShadowRootInit;
    }>) => FoundationElementRegistry<    {
    baseName: string;
    styles: ElementStyles;
    template: ViewTemplate<any, any>;
    shadowOptions: ShadowRootInit;
    }, G2PlotChart>;
    register(container?: Container, ...rest: any[]): void;
};

/**
 * The g2lot chart template.
 * @param prefix - The design system prefix to use. Defaults to 'foundation'.
 * @returns A g2plot chart template prefixed with the correct design system.
 * @public
 */
export declare const g2plotChartTemplate: ViewTemplate;

/**
 * Register the Rapid Design System G2Plot shape
 * @internal
 */
export declare const registerRapidShape: () => void;

export { }
